@@ -4,6 +4,7 @@ True, False = 1==1, 0==1
 
 import threading
 from util.threadinglocal import local as threading_local
+import sys
 import re
 import warnings
 import atexit
@@ -31,21 +32,55 @@ def _closeConnection(ref):
     if conn is not None:
         conn.close()
 
+class ConsoleWriter:
+    def __init__(self, loglevel):
+        self.loglevel = loglevel
+        self.logfile = getattr(sys, loglevel or "stdout")
+    def write(self, text):
+        self.logfile.write(text + '\n')
+
+class LogWriter:
+    def __init__(self, logger, loglevel):
+        self.logger = logger
+        self.loglevel = loglevel
+        self.logmethod = getattr(logger, loglevel)
+    def write(self, text):
+        self.logmethod(text)
+
+def makeDebugWriter(loggerName, loglevel):
+    if not loggerName:
+        return ConsoleWriter(loglevel)
+    import logging
+    logger = logging.getLogger(loggerName)
+    return LogWriter(logger, loglevel)
+
+class Boolean(object):
+    """A bool class that also understands some special string keywords (yes/no, true/false, on/off, 1/0)"""
+    _keywords = {'1': True, 'yes': True, 'true': True, 'on': True,
+                 '0': False, 'no': False, 'false': False, 'off': False}
+    def __new__(cls, value):
+        try:
+            return Boolean._keywords[value.lower()]
+        except (AttributeError, KeyError):
+            return bool(value)
+
 class DBConnection:
 
     def __init__(self, name=None, debug=False, debugOutput=False,
                  cache=True, style=None, autoCommit=True,
-                 debugThreading=False, registry=None):
+                 debugThreading=False, registry=None,
+                 logger=None, loglevel=None):
         self.name = name
-        self.debug = debug
-        self.debugOutput = debugOutput
-        self.debugThreading = debugThreading
-        self.cache = CacheSet(cache=cache)
-        self.doCache = cache
+        self.debug = Boolean(debug)
+        self.debugOutput = Boolean(debugOutput)
+        self.debugThreading = Boolean(debugThreading)
+        self.debugWriter = makeDebugWriter(logger, loglevel)
+        self.doCache = Boolean(cache)
+        self.cache = CacheSet(cache=self.doCache)
         self.style = style
         self._connectionNumbers = {}
         self._connectionCount = 1
-        self.autoCommit = autoCommit
+        self.autoCommit = Boolean(autoCommit)
         self.registry = registry or None
         classregistry.registry(self.registry).addCallback(
             self.soClassAdded)
@@ -53,7 +88,7 @@ class DBConnection:
         atexit.register(_closeConnection, weakref.ref(self))
 
     def uri(self):
-        auth = getattr(self, 'user', None) or ''
+        auth = getattr(self, 'user', '')
         if auth:
             if self.password:
                 auth = auth + ':' + self.password
@@ -300,7 +335,8 @@ class DBAPI(DBConnection):
             threadName = (':' + threadName + ' '*(8-len(threadName)))
         else:
             threadName = ''
-        print '%(n)2i%(threadName)s/%(name)s%(spaces)s%(sep)s %(s)s' % locals()
+        msg = '%(n)2i%(threadName)s/%(name)s%(spaces)s%(sep)s %(s)s' % locals()
+        self.debugWriter.write(msg)
 
     def _executeRetry(self, conn, cursor, query):
         if self.debug:
@@ -450,7 +486,7 @@ class DBAPI(DBConnection):
         if type(join) is str:
             join_str = ' ' + join
         elif isinstance(join, sqlbuilder.SQLJoin):
-            if tables and join.table1:
+            if join.table1:
                 join_str = ", "
             else:
                 join_str = ' '
@@ -458,11 +494,13 @@ class DBAPI(DBConnection):
         else:
             join_str = ""
             for j in join:
-                if tables and j.table1:
+                if j.table1:
                     sep = ", "
                 else:
                     sep = ' '
                 join_str += sep + self.sqlrepr(j)
+        if not tables and join_str.startswith(','):
+            join_str = join_str[1:].strip()
         return join_str
 
     def _addWhereClause(self, select, startSelect, limit=1, order=1):
@@ -564,7 +602,7 @@ class DBAPI(DBConnection):
             if isinstance(tableCreateSQLs, tuple):
                 tableCreateSQLs = list(tableCreateSQLs)
             assert isinstance(tableCreateSQLs,list), (
-                'Unable to create a list from %s.sqlmeta.createSQL' % 
+                'Unable to create a list from %s.sqlmeta.createSQL' %
                 (soClass.__name__))
         return tableCreateSQLs or []
 
@@ -1039,8 +1077,9 @@ class ConnectionURIOpener(object):
     def connectionForURI(self, uri, **args):
         if args:
             if '?' not in uri:
-                uri += '?'
-            uri += urllib.urlencode(args)
+                uri += '?' + urllib.urlencode(args)
+            else:
+                uri += '&' + urllib.urlencode(args)
         if self.cachedURIs.has_key(uri):
             return self.cachedURIs[uri]
         if uri.find(':') != -1:
