@@ -177,10 +177,8 @@ class PostgresConnection(DBAPI):
                    (tableName,
                     column.postgresCreateSQL()))
 
-    def delColumn(self, tableName, column):
-        self.query('ALTER TABLE %s DROP COLUMN %s' %
-                   (tableName,
-                    column.dbName))
+    def delColumn(self, sqlmeta, column):
+        self.query('ALTER TABLE %s DROP COLUMN %s' % (sqlmeta.table, column.dbName))
 
     def columnsFromSchema(self, tableName, soClass):
 
@@ -257,7 +255,9 @@ class PostgresConnection(DBAPI):
         return results
 
     def guessClass(self, t):
-        if t.count('int'):
+        if t.count('point'): # poINT before INT
+            return col.StringCol, {}
+        elif t.count('int'):
             return col.IntCol, {}
         elif t.count('varying') or t.count('varchar'):
             if '(' in t:
